@@ -1,6 +1,6 @@
 """Initialize database package."""
 
-from mgedb.db import MGEdb
+from mgedb.db import MGEdb, MGErecord, MgeType
 from mgedb.io import Sequence
 from mgedb.io import SequencesType as Sequences
 from mgedb.version import __version__
